**robo-utils** 

useful functions for mobile robotics 
and related applications


Installation: 

$ **pip** install robo-utils

For documentation see https://robo-utils.readthedocs.io/en/latest/





